Struct amazon_sp_finances::models::list_financial_events_payload::ListFinancialEventsPayload
source · [−]pub struct ListFinancialEventsPayload {
pub next_token: Option<String>,
pub financial_events: Option<Box<FinancialEvents>>,
}Expand description
ListFinancialEventsPayload : The payload for the listFinancialEvents operation.
Fields
next_token: Option<String>When present and not empty, pass this string token in the next request to return the next response page.
financial_events: Option<Box<FinancialEvents>>Implementations
sourceimpl ListFinancialEventsPayload
impl ListFinancialEventsPayload
sourcepub fn new() -> ListFinancialEventsPayload
pub fn new() -> ListFinancialEventsPayload
The payload for the listFinancialEvents operation.